@@ -132,7 +132,21 @@ class CfnGitHubRepository(
         :param repository_description: A comment or description about the new repository. This description is displayed in GitHub after the repository is created.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnGitHubRepository.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                repository_name: builtins.str,
+                repository_owner: builtins.str,
+                code: typing.Optional[typing.Union[typing.Union["CfnGitHubRepository.CodeProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]] = None,
+                connection_arn: typing.Optional[builtins.str] = None,
+                enable_issues: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+                is_private: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+                repository_access_token: typing.Optional[builtins.str] = None,
+                repository_description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnGitHubRepositoryProps(
@@ -155,7 +169,9 @@ class CfnGitHubRepository(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnGitHubRepository.inspect)
+            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -168,7 +184,9 @@ class CfnGitHubRepository(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnGitHubRepository._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -195,7 +213,9 @@ class CfnGitHubRepository(
     @repository_name.setter
     def repository_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "repository_name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryName", value)
 
@@ -213,7 +233,9 @@ class CfnGitHubRepository(
     @repository_owner.setter
     def repository_owner(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "repository_owner").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryOwner", value)
 
@@ -234,7 +256,11 @@ class CfnGitHubRepository(
         value: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", aws_cdk.core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "code").fset)
+            def stub(
+                value: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", aws_cdk.core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "code", value)
 
@@ -250,7 +276,9 @@ class CfnGitHubRepository(
     @connection_arn.setter
     def connection_arn(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "connection_arn").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionArn", value)
 
@@ -273,7 +301,11 @@ class CfnGitHubRepository(
         value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "enable_issues").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableIssues", value)
 
@@ -296,7 +328,11 @@ class CfnGitHubRepository(
         value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "is_private").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isPrivate", value)
 
@@ -312,7 +348,9 @@ class CfnGitHubRepository(
     @repository_access_token.setter
     def repository_access_token(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "repository_access_token").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryAccessToken", value)
 
@@ -330,7 +368,9 @@ class CfnGitHubRepository(
     @repository_description.setter
     def repository_description(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "repository_description").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryDescription", value)
 
@@ -371,7 +411,12 @@ class CfnGitHubRepository(
                 )
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(CfnGitHubRepository.CodeProperty.__init__)
+                def stub(
+                    *,
+                    s3: typing.Union[aws_cdk.core.IResolvable, typing.Union["CfnGitHubRepository.S3Property", typing.Dict[str, typing.Any]]],
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument s3", value=s3, expected_type=type_hints["s3"])
             self._values: typing.Dict[str, typing.Any] = {
                 "s3": s3,
@@ -443,7 +488,14 @@ class CfnGitHubRepository(
                 )
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(CfnGitHubRepository.S3Property.__init__)
+                def stub(
+                    *,
+                    bucket: builtins.str,
+                    key: builtins.str,
+                    object_version: typing.Optional[builtins.str] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
                 check_type(argname="argument key", value=key, expected_type=type_hints["key"])
                 check_type(argname="argument object_version", value=object_version, expected_type=type_hints["object_version"])
@@ -564,7 +616,19 @@ class CfnGitHubRepositoryProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnGitHubRepositoryProps.__init__)
+            def stub(
+                *,
+                repository_name: builtins.str,
+                repository_owner: builtins.str,
+                code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]] = None,
+                connection_arn: typing.Optional[builtins.str] = None,
+                enable_issues: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+                is_private: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+                repository_access_token: typing.Optional[builtins.str] = None,
+                repository_description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
             check_type(argname="argument repository_owner", value=repository_owner, expected_type=type_hints["repository_owner"])
             check_type(argname="argument code", value=code, expected_type=type_hints["code"])
@@ -751,7 +815,20 @@ class GitHubRepositoryProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GitHubRepositoryProps.__init__)
+            def stub(
+                *,
+                access_token: aws_cdk.core.SecretValue,
+                contents_bucket: aws_cdk.aws_s3.IBucket,
+                contents_key: builtins.str,
+                owner: builtins.str,
+                repository_name: builtins.str,
+                contents_s3_version: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                enable_issues: typing.Optional[builtins.bool] = None,
+                visibility: typing.Optional["RepositoryVisibility"] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument access_token", value=access_token, expected_type=type_hints["access_token"])
             check_type(argname="argument contents_bucket", value=contents_bucket, expected_type=type_hints["contents_bucket"])
             check_type(argname="argument contents_key", value=contents_key, expected_type=type_hints["contents_key"])
@@ -1031,7 +1108,22 @@ class GitHubRepository(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GitHubRepository.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                access_token: aws_cdk.core.SecretValue,
+                contents_bucket: aws_cdk.aws_s3.IBucket,
+                contents_key: builtins.str,
+                owner: builtins.str,
+                repository_name: builtins.str,
+                contents_s3_version: typing.Optional[builtins.str] = None,
+                description: typing.Optional[builtins.str] = None,
+                enable_issues: typing.Optional[builtins.bool] = None,
+                visibility: typing.Optional[RepositoryVisibility] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitHubRepositoryProps(
